function [f,A,b,equalityvector,integervector]=altruism_endogLP(M,p,assignquant,e)
% This function formulates the Mixed Integer Linear Programming problem
% to recover "pi" in the benchmark case of Altruism.
%
% Inputs: 
% M number of group members (restricted to 2 in this code)
% p price vector
% assignquant vector containing observed quantities (first T rows: member 1
% / second set of T rows: member 2)
% afriat index e (= 1)
%
% Outputs:
% objective function f (trivial)
% A matrix of LHS
% b matrix of RHS
% equalityvector: equality or inequality constraint
% integervector: integer or continuous variable

%% ***CHECK INPUT PARAMETERS***
T=size(p,1);
N=size(p,2);

% Define smallnumber: used for a<b restrictions (modelled as
% a<=b-smallnumber)
global smallnumber
smallnumber=0.0001;

global largenumber % larger than budgets
largenumber=100;

%% ***Define dimensions of the problem: decision variables and nr of constraints***
% Define decision variables
nrx=M*T*T; % binary pref. relations
nrppriv=M*M*T*N; % shadow prices for egoism and altruism p11,p12,p21,p22
nrteta=1; % theta parameter
nrvars=nrx+nrppriv+nrteta;

% Define for each variable whether it is binary integer ('b'), general integer ('i'),
% or continuous ('c')
intx=repmat('b',M*T*T,1);
intppriv=repmat('c',M*M*T*N,1);
intteta=repmat('c',nrteta,1);
integervector=[intx;intppriv;intteta]; % vector of length nrvars. Contains 'b' for binary, 'i' for general integer and 'c' for continuous

%% FORMULATE BIP PROBLEM
% Make objective function
f=zeros(nrvars,1); % all-zero vector
f(end,1)=1;

A=zeros(M*T*T+M*T*(T-1)*(T-2)+M*T*T+2*M*T*N,nrvars);
b=zeros(M*T*T+M*T*(T-1)*(T-2)+M*T*T+2*M*T*N,1);

equalityvector=zeros(M*T*T+M*T*(T-1)*(T-2)+M*T*T+2*M*T*N,1);

%% Condition set 1: GARP
r=1;

% GARP opening condition
for m=1:M
    for t=1:T
        for v=1:T
            A(r,(m-1)*T*T+(t-1)*T+v)=-largenumber;
            for n=1:N
                for i=1:M
                    A(r,nrx+(m-1)*M*T*N+(i-1)*T*N+(t-1)*N+n)=-assignquant((i-1)*T+v,n)+e*assignquant((i-1)*T+t,n);
                end
            end
            b(r,1)=-smallnumber;
            equalityvector(r,1)=0;
            r=r+1;
        end
    end
end

% Transitivity
for m=1:M
    for s=1:T
        for u=[1:s-1,s+1:T]
            for t=[1:u-1,u+1:T]
                if not(isequal(s,t))
                    A(r,(m-1)*T*T+(s-1)*T+u)=1;
                    A(r,(m-1)*T*T+(u-1)*T+t)=1;
                    A(r,(m-1)*T*T+(s-1)*T+t)=-1;
                    b(r,1)=1;
                    equalityvector(r,1)=0;
                    r=r+1;
                end % if
            end % for t
        end % for u
    end % for s
end

% GARP closing condition
for m=1:M
    for t=1:T
        for v=1:T
            A(r,(m-1)*T*T+(t-1)*T+v)=largenumber;
            for n=1:N
                for i=1:2
                    A(r,nrx+(m-1)*M*T*N+(i-1)*T*N+(v-1)*N+n)=-assignquant((i-1)*T+t,n)+e*assignquant((i-1)*T+v,n);
                end
            end
            b(r,1)=largenumber;
            equalityvector(r,1)=0;
            r=r+1;
        end
    end
end

%% Condition set 2: FOCs

for m=1:M
    for t=1:T
        for n=1:N
            A(r,nrx+(m-1)*T*N+(t-1)*N+n)=1;
            A(r,nrx+M*T*N+(m-1)*T*N+(t-1)*N+n)=1;
            b(r,1)=p(t,n);
            if assignquant((m-1)*T+t,n)>0
                equalityvector(r,1)=1;
            else
                equalityvector(r,1)=0;
            end
            r=r+1;
        end
    end
end

%% Condition set 3: altruism restrictions
for m=1:M
    for t=1:T
        for n=1:N
            for i=1:2
                if m~=i
                    A(r,nrx+(m-1)*M*T*N+(i-1)*T*N+(t-1)*N+n)=1;
                    A(r,nrx+nrppriv+1)=-p(t,n);
                    b(r,1)=0;
                    equalityvector(r,1)=0;
                    r=r+1;
                end
            end
        end
    end
end

return